@@ -4,7 +4,7 @@ Main interface for honeycode service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_honeycode import (
         Client,
         HoneycodeClient,
@@ -14,10 +14,8 @@ Usage::
         QueryTableRowsPaginator,
     )
 
-    session = boto3.Session()
-
-    client: HoneycodeClient = boto3.client("honeycode")
-    session_client: HoneycodeClient = session.client("honeycode")
+    session = Session()
+    client: HoneycodeClient = session.client("honeycode")
 
     list_table_columns_paginator: ListTableColumnsPaginator = client.get_paginator("list_table_columns")
     list_table_rows_paginator: ListTableRowsPaginator = client.get_paginator("list_table_rows")
