@@ -6,20 +6,21 @@ Type annotations for honeycode service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_honeycode.literals import FormatType
+    from mypy_boto3_honeycode.literals import ErrorCodeType
 
-    data: FormatType = "ACCOUNTING"
+    data: ErrorCodeType = "ACCESS_DENIED"
     ```
 """
 import sys
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
 
 
 __all__ = (
+    "ErrorCodeType",
     "FormatType",
     "ImportDataCharacterEncodingType",
     "ImportSourceDataFormatType",
@@ -34,6 +35,22 @@ __all__ = (
 )
 
 
+ErrorCodeType = Literal[
+    "ACCESS_DENIED",
+    "FILE_EMPTY_ERROR",
+    "FILE_NOT_FOUND_ERROR",
+    "FILE_PARSING_ERROR",
+    "FILE_SIZE_LIMIT_ERROR",
+    "INVALID_FILE_TYPE_ERROR",
+    "INVALID_IMPORT_OPTIONS_ERROR",
+    "INVALID_TABLE_COLUMN_ID_ERROR",
+    "INVALID_TABLE_ID_ERROR",
+    "INVALID_URL_ERROR",
+    "RESOURCE_NOT_FOUND_ERROR",
+    "SYSTEM_LIMIT_ERROR",
+    "TABLE_NOT_FOUND_ERROR",
+    "UNKNOWN_ERROR",
+]
 FormatType = Literal[
     "ACCOUNTING",
     "AUTO",
@@ -44,6 +61,7 @@ FormatType = Literal[
     "NUMBER",
     "PERCENTAGE",
     "ROWLINK",
+    "ROWSET",
     "TEXT",
     "TIME",
 ]
@@ -66,10 +84,12 @@ ServiceName = Literal[
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -84,12 +104,14 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
     "braket",
     "budgets",
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -137,6 +159,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -158,6 +181,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -184,6 +208,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -197,6 +222,7 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
     "kafka",
@@ -242,7 +268,9 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -256,6 +284,7 @@ ServiceName = Literal[
     "opsworkscm",
     "organizations",
     "outposts",
+    "panorama",
     "personalize",
     "personalize-events",
     "personalize-runtime",
@@ -270,11 +299,13 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -284,6 +315,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -341,6 +373,7 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
 PaginatorName = Literal["list_table_columns", "list_table_rows", "list_tables", "query_table_rows"]
