@@ -13,20 +13,21 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Mapping, Sequence
+from typing import Dict, List, Mapping, Sequence
 
 from .literals import (
+    ErrorCodeType,
     FormatType,
     ImportDataCharacterEncodingType,
     TableDataImportJobStatusType,
     UpsertActionType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -66,6 +67,8 @@ __all__ = (
     "ListTableRowsResultTypeDef",
     "ListTablesRequestRequestTypeDef",
     "ListTablesResultTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListTagsForResourceResultTypeDef",
     "PaginatorConfigTypeDef",
     "QueryTableRowsRequestRequestTypeDef",
     "QueryTableRowsResultTypeDef",
@@ -79,6 +82,8 @@ __all__ = (
     "TableDataImportJobMetadataTypeDef",
     "TableRowTypeDef",
     "TableTypeDef",
+    "TagResourceRequestRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
     "UpdateRowDataTypeDef",
     "UpsertRowDataTypeDef",
     "UpsertRowsResultTypeDef",
@@ -223,6 +228,7 @@ CellInputTypeDef = TypedDict(
     "CellInputTypeDef",
     {
         "fact": str,
+        "facts": Sequence[str],
     },
     total=False,
 )
@@ -234,6 +240,7 @@ CellTypeDef = TypedDict(
         "format": FormatType,
         "rawValue": str,
         "formattedValue": str,
+        "formattedValues": List[str],
     },
     total=False,
 )
@@ -302,6 +309,7 @@ DescribeTableDataImportJobResultTypeDef = TypedDict(
         "jobStatus": TableDataImportJobStatusType,
         "message": str,
         "jobMetadata": "TableDataImportJobMetadataTypeDef",
+        "errorCode": ErrorCodeType,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -544,6 +552,21 @@ ListTablesResultTypeDef = TypedDict(
     },
 )
 
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+    },
+)
+
+ListTagsForResourceResultTypeDef = TypedDict(
+    "ListTagsForResourceResultTypeDef",
+    {
+        "tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
@@ -595,7 +618,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
@@ -693,6 +716,22 @@ TableTypeDef = TypedDict(
     total=False,
 )
 
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tags": Mapping[str, str],
+    },
+)
+
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tagKeys": Sequence[str],
+    },
+)
+
 UpdateRowDataTypeDef = TypedDict(
     "UpdateRowDataTypeDef",
     {
